"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../../utils/constants");

var _useModes2 = _interopRequireDefault(require("../../hooks/use-modes"));

var _spectacleModeDisplay;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Kbar default actions, those that do not depend on dynamic logic, can be added here.
 * To register actions dynamically use 'useRegisterActions' and make sure the action
 * is registed within the KBarProvider.
 * @see https://kbar.vercel.app/docs/concepts/actions
 * Kbar action shortcuts dont seem to support all keybindings. If you need to utilize
 * keybindings that are not supported you'll have to implement the keybinding seperately.
 * @see useMousetrap
 * To display keybindings that are not supported in the Kbar results, please use
 * KEYBOARD_SHORTCUTS instead of Kbar actions 'shortcut' property.
 * @see CommandBarResults getShortcutKeys
 */
var spectacleModeDisplay = (_spectacleModeDisplay = {}, _defineProperty(_spectacleModeDisplay, _constants.SPECTACLE_MODES.DEFAULT_MODE, 'Default Mode'), _defineProperty(_spectacleModeDisplay, _constants.SPECTACLE_MODES.PRESENTER_MODE, 'Presenter Mode'), _defineProperty(_spectacleModeDisplay, _constants.SPECTACLE_MODES.OVERVIEW_MODE, 'Overview Mode'), _defineProperty(_spectacleModeDisplay, _constants.SPECTACLE_MODES.PRINT_MODE, 'Print Mode'), _defineProperty(_spectacleModeDisplay, _constants.SPECTACLE_MODES.EXPORT_MODE, 'Export Mode'), _spectacleModeDisplay);

var getName = function getName(currentMode, mode) {
  var defaultMode = _constants.SPECTACLE_MODES.DEFAULT_MODE;
  return currentMode === mode ? "\u2190 Back to ".concat(spectacleModeDisplay[defaultMode]) : spectacleModeDisplay[mode];
};

var useCommandBarActions = function useCommandBarActions() {
  var _useModes = (0, _useModes2.default)(),
      toggleMode = _useModes.toggleMode,
      getCurrentMode = _useModes.getCurrentMode;

  var currentMode = getCurrentMode();
  return [{
    id: _constants.KEYBOARD_SHORTCUTS_IDS.PRESENTER_MODE,
    name: getName(currentMode, _constants.SPECTACLE_MODES.PRESENTER_MODE),
    keywords: 'presenter',
    perform: function perform() {
      return toggleMode({
        newMode: _constants.SPECTACLE_MODES.PRESENTER_MODE
      });
    },
    section: 'Mode'
  }, {
    id: _constants.KEYBOARD_SHORTCUTS_IDS.OVERVIEW_MODE,
    name: getName(currentMode, _constants.SPECTACLE_MODES.OVERVIEW_MODE),
    keywords: 'overview',
    perform: function perform() {
      return toggleMode({
        newMode: _constants.SPECTACLE_MODES.OVERVIEW_MODE
      });
    },
    section: 'Mode'
  }, {
    id: _constants.KEYBOARD_SHORTCUTS_IDS.PRINT_MODE,
    name: getName(currentMode, _constants.SPECTACLE_MODES.PRINT_MODE),
    keywords: 'export',
    perform: function perform() {
      return toggleMode({
        newMode: _constants.SPECTACLE_MODES.PRINT_MODE
      });
    },
    section: 'Mode'
  }, {
    id: _constants.KEYBOARD_SHORTCUTS_IDS.EXPORT_MODE,
    name: getName(currentMode, _constants.SPECTACLE_MODES.EXPORT_MODE),
    keywords: 'export',
    perform: function perform() {
      return toggleMode({
        newMode: _constants.SPECTACLE_MODES.EXPORT_MODE
      });
    },
    section: 'Mode'
  }];
};

var _default = useCommandBarActions;
exports.default = _default;