import * as React from 'react';
import { SlideProps } from './slide/slide';
import { CodePaneProps } from './code-pane';
/**
 * Layouts to consider:
 * - Intro
 */
declare const _default: {
    Full: ({ children, ...rest }: SlideProps) => JSX.Element;
    Center: ({ children, ...rest }: SlideProps) => JSX.Element;
    TwoColumn: ({ left, right, ...rest }: Omit<SlideProps, "children"> & {
        left: React.ReactNode;
        right: React.ReactNode;
    }) => JSX.Element;
    List: ({ title, items, listType, animateListItems, titleProps, listProps, ...rest }: Omit<SlideProps, "children"> & {
        title?: string | undefined;
        listType?: "unordered" | "ordered" | undefined;
        items: React.ReactNode[];
        animateListItems?: boolean | undefined;
        titleProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        listProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
    }) => JSX.Element;
    Section: ({ sectionProps, children }: SlideProps & {
        sectionProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
    }) => JSX.Element;
    BigFact: ({ children, factInformation, factProps, factFontSize, factInformationProps, ...rest }: SlideProps & {
        factInformation?: React.ReactNode;
        factProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        factFontSize?: string | undefined;
        factInformationProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
    }) => JSX.Element;
    Quote: ({ children, quoteProps, attribution, attributionProps, ...rest }: SlideProps & {
        quoteProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        attribution: React.ReactNode;
        attributionProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
    }) => JSX.Element;
    Statement: ({ statementProps, children }: SlideProps & {
        statementProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
    }) => JSX.Element;
    Code: ({ children, language, title, titleProps, codePaneProps, ...rest }: Omit<SlideProps, "children"> & {
        children: string;
        language: string;
        title?: React.ReactNode;
        titleProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        codePaneProps?: CodePaneProps | undefined;
    }) => JSX.Element;
    MultiCodeLayout: ({ codeBlocks, title, titleProps, numColumns, ...rest }: Omit<SlideProps, "children"> & {
        codeBlocks: (Omit<CodePaneProps, "children"> & {
            code: string;
            description?: React.ReactNode;
            descriptionProps?: ({
                [x: string]: any;
                [x: number]: any;
                [x: symbol]: any;
            } & {
                theme?: any;
            } & {
                as?: string | React.ComponentType<any> | undefined;
                forwardedAs?: string | React.ComponentType<any> | undefined;
            }) | undefined;
        })[];
        title?: React.ReactNode;
        titleProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        numColumns?: number | undefined;
    }) => JSX.Element;
    HorizontalImage: ({ src, alt, title, titleProps, description, descriptionProps, imgProps, imgContainerProps, objectFit, ...rest }: Omit<SlideProps, "children"> & {
        src: string;
        alt: string;
        title?: React.ReactNode;
        titleProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        description?: React.ReactNode;
        descriptionProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
        imgContainerProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        objectFit?: import("csstype").Property.ObjectFit | undefined;
    }) => JSX.Element;
    VerticalImage: ({ src, alt, title, titleProps, listType, listItems, animateListItems, listProps, imgProps, imgContainerProps, position, objectFit, ...rest }: Omit<SlideProps, "children"> & {
        src: string;
        alt: string;
        listItems: React.ReactNode[];
        title?: React.ReactNode;
        titleProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        listType?: "unordered" | "ordered" | undefined;
        animateListItems?: boolean | undefined;
        listProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
        imgContainerProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        position?: "left" | "right" | undefined;
        objectFit?: import("csstype").Property.ObjectFit | undefined;
    }) => JSX.Element;
    ThreeUpImage: ({ primary, top, bottom, ...rest }: Omit<SlideProps, "children"> & {
        primary: {
            src: string;
            alt: string;
            objectFit?: import("csstype").Property.ObjectFit | undefined;
            position?: "left" | "right" | undefined;
            imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
            imgContainerProps?: ({
                [x: string]: any;
                [x: number]: any;
                [x: symbol]: any;
            } & {
                theme?: any;
            } & {
                as?: string | React.ComponentType<any> | undefined;
                forwardedAs?: string | React.ComponentType<any> | undefined;
            }) | undefined;
        };
        top: {
            src: string;
            alt: string;
            objectFit?: import("csstype").Property.ObjectFit | undefined;
            imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
            imgContainerProps?: ({
                [x: string]: any;
                [x: number]: any;
                [x: symbol]: any;
            } & {
                theme?: any;
            } & {
                as?: string | React.ComponentType<any> | undefined;
                forwardedAs?: string | React.ComponentType<any> | undefined;
            }) | undefined;
        };
        bottom: {
            src: string;
            alt: string;
            objectFit?: import("csstype").Property.ObjectFit | undefined;
            imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
            imgContainerProps?: ({
                [x: string]: any;
                [x: number]: any;
                [x: symbol]: any;
            } & {
                theme?: any;
            } & {
                as?: string | React.ComponentType<any> | undefined;
                forwardedAs?: string | React.ComponentType<any> | undefined;
            }) | undefined;
        };
    }) => JSX.Element;
    FullBleedImage: ({ src, alt, imgProps, imgContainerProps, objectFit, ...rest }: Omit<SlideProps, "children"> & {
        src: string;
        alt: string;
        imgProps?: React.ImgHTMLAttributes<HTMLImageElement> | undefined;
        imgContainerProps?: ({
            [x: string]: any;
            [x: number]: any;
            [x: symbol]: any;
        } & {
            theme?: any;
        } & {
            as?: string | React.ComponentType<any> | undefined;
            forwardedAs?: string | React.ComponentType<any> | undefined;
        }) | undefined;
        objectFit?: import("csstype").Property.ObjectFit | undefined;
    }) => JSX.Element;
};
export default _default;
//# sourceMappingURL=slide-layout.d.ts.map