"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getKeyForOS = getKeyForOS;
exports.isPlatformMacOS = isPlatformMacOS;
exports.prettifyShortcut = prettifyShortcut;

/*
 * Check if operating system is MacOS
 */
function isPlatformMacOS() {
  return /Mac|iPad/.test(navigator.userAgent);
}
/*
 * Get operating system specific key
 */


function getKeyForOS(key) {
  var isMacOS = isPlatformMacOS();
  var replacementKeyMap = {
    alt: isMacOS ? '⌥' : 'Alt',
    ctrl: isMacOS ? '^' : 'Ctrl',
    mod: isMacOS ? '⌘' : 'Ctrl',
    shift: isMacOS ? '⇧' : 'Shift'
  };
  return replacementKeyMap[key];
}
/**
 * Prettifies keyboard shortcuts in a platform-agnostic way.
 */


function prettifyShortcut(shortcut) {
  var _shortcut = typeof shortcut === 'string' ? shortcut : shortcut.join('+');

  return _shortcut.toLowerCase().replace('alt', getKeyForOS('alt')).replace('ctrl', getKeyForOS('ctrl')).replace('mod', getKeyForOS('mod')).replace('shift', getKeyForOS('shift')).replace('left', '←').replace('right', '→').split('+').map(function (s) {
    return s.charAt(0).toUpperCase() + s.slice(1);
  });
}